@@ -43,6 +43,12 @@ mock_autoscaling = lazy_load(".autoscaling", "mock_autoscaling")
 mock_lambda = lazy_load(
     ".awslambda", "mock_lambda", boto3_name="lambda", backend="lambda_backends"
 )
+mock_lambda_simple = lazy_load(
+    ".awslambda_simple",
+    "mock_lambda_simple",
+    boto3_name="lambda",
+    backend="lambda_simple_backends",
+)
 mock_batch = lazy_load(".batch", "mock_batch")
 mock_batch_simple = lazy_load(
     ".batch_simple",
@@ -100,12 +106,14 @@ mock_firehose = lazy_load(".firehose", "mock_firehose")
 mock_forecast = lazy_load(".forecast", "mock_forecast")
 mock_greengrass = lazy_load(".greengrass", "mock_greengrass")
 mock_glacier = lazy_load(".glacier", "mock_glacier")
-mock_glue = lazy_load(".glue", "mock_glue", boto3_name="glue")
+mock_glue = lazy_load(".glue", "mock_glue")
 mock_guardduty = lazy_load(".guardduty", "mock_guardduty")
 mock_iam = lazy_load(".iam", "mock_iam")
 mock_identitystore = lazy_load(".identitystore", "mock_identitystore")
+mock_inspector2 = lazy_load(".inspector2", "mock_inspector2")
 mock_iot = lazy_load(".iot", "mock_iot")
 mock_iotdata = lazy_load(".iotdata", "mock_iotdata", boto3_name="iot-data")
+mock_ivs = lazy_load(".ivs", "mock_ivs")
 mock_kinesis = lazy_load(".kinesis", "mock_kinesis")
 mock_kinesisvideo = lazy_load(".kinesisvideo", "mock_kinesisvideo")
 mock_kinesisvideoarchivedmedia = lazy_load(
@@ -150,9 +158,7 @@ mock_resourcegroupstaggingapi = lazy_load(
 )
 mock_robomaker = lazy_load(".robomaker", "mock_robomaker")
 mock_route53 = lazy_load(".route53", "mock_route53")
-mock_route53resolver = lazy_load(
-    ".route53resolver", "mock_route53resolver", boto3_name="route53resolver"
-)
+mock_route53resolver = lazy_load(".route53resolver", "mock_route53resolver")
 mock_s3 = lazy_load(".s3", "mock_s3")
 mock_s3control = lazy_load(".s3control", "mock_s3control")
 mock_sagemaker = lazy_load(".sagemaker", "mock_sagemaker")
@@ -212,7 +218,7 @@ mock_all = MockAll
 # logging.getLogger('boto').setLevel(logging.CRITICAL)
 
 __title__ = "moto"
-__version__ = "4.2.5"
+__version__ = "4.2.9"
 
 
 try:
