@@ -7,8 +7,6 @@ from gzip import GzipFile
 from typing import Any, Dict, Iterable, List, Optional, Tuple, Union
 from sys import platform
 
-import docker
-import docker.errors
 import hashlib
 import io
 import logging
@@ -157,6 +155,8 @@ class _DockerDataVolumeContext:
         with self.__class__._lock:
             self._vol_ref.refcount -= 1  # type: ignore[union-attr]
             if self._vol_ref.refcount == 0:  # type: ignore[union-attr]
+                import docker.errors
+
                 try:
                     self._vol_ref.volume.remove()  # type: ignore[union-attr]
                 except docker.errors.APIError as e:
@@ -240,6 +240,8 @@ class _DockerDataVolumeLayerContext:
         with self.__class__._lock:
             self._vol_ref.refcount -= 1  # type: ignore[union-attr]
             if self._vol_ref.refcount == 0:  # type: ignore[union-attr]
+                import docker.errors
+
                 try:
                     self._vol_ref.volume.remove()  # type: ignore[union-attr]
                 except docker.errors.APIError as e:
@@ -371,6 +373,11 @@ class LayerVersion(CloudFormationModel):
                     self.code_sha_256,
                     self.code_digest,
                 ) = _s3_content(key)
+            else:
+                self.code_bytes = b""
+                self.code_size = 0
+                self.code_sha_256 = ""
+                self.code_digest = ""
 
     @property
     def arn(self) -> str:
@@ -852,6 +859,9 @@ class LambdaFunction(CloudFormationModel, DockerModel):
             return s
 
     def _invoke_lambda(self, event: Optional[str] = None) -> Tuple[str, bool, str]:
+        import docker
+        import docker.errors
+
         # Create the LogGroup if necessary, to write the result to
         self.logs_backend.ensure_log_group(self.logs_group_name)
         # TODO: context not yet implemented
@@ -1344,8 +1354,10 @@ class LambdaStorage(object):
         return None
 
     def _get_function_aliases(self, function_name: str) -> Dict[str, LambdaAlias]:
-        fn = self.get_function_by_name_or_arn(function_name)
-        return self._aliases[fn.function_arn]
+        fn = self.get_function_by_name_or_arn_with_qualifier(function_name)
+        # Split ARN to retrieve an ARN without a qualifier present
+        [arn, _, _] = self.split_function_arn(fn.function_arn)
+        return self._aliases[arn]
 
     def delete_alias(self, name: str, function_name: str) -> None:
         aliases = self._get_function_aliases(function_name)
@@ -1367,7 +1379,9 @@ class LambdaStorage(object):
         description: str,
         routing_config: str,
     ) -> LambdaAlias:
-        fn = self.get_function_by_name_or_arn(function_name, function_version)
+        fn = self.get_function_by_name_or_arn_with_qualifier(
+            function_name, function_version
+        )
         aliases = self._get_function_aliases(function_name)
         if name in aliases:
             arn = f"arn:aws:lambda:{self.region_name}:{self.account_id}:function:{function_name}:{name}"
@@ -1396,34 +1410,71 @@ class LambdaStorage(object):
         alias = self.get_alias(name, function_name)
 
         # errors if new function version doesn't exist
-        self.get_function_by_name_or_arn(function_name, function_version)
+        self.get_function_by_name_or_arn_with_qualifier(function_name, function_version)
 
         alias.update(description, function_version, routing_config)
         return alias
 
-    def get_function_by_name(
-        self, name: str, qualifier: Optional[str] = None
-    ) -> Optional[LambdaFunction]:
+    def get_function_by_name_forbid_qualifier(self, name: str) -> LambdaFunction:
+        """
+        Get function by name forbidding a qualifier
+        :raises: UnknownFunctionException if function not found
+        :raises: InvalidParameterValue if qualifier is provided
+        """
+
+        if name.count(":") == 1:
+            raise InvalidParameterValueException("Cannot provide qualifier")
+
         if name not in self._functions:
-            return None
+            raise self.construct_unknown_function_exception(name)
 
+        return self._get_latest(name)
+
+    def get_function_by_name_with_qualifier(
+        self, name: str, qualifier: Optional[str] = None
+    ) -> LambdaFunction:
+        """
+        Get function by name with an optional qualifier
+        :raises: UnknownFunctionException if function not found
+        """
+
+        # Function name may contain an alias
+        # <fn_name>:<alias_name>
+        if ":" in name:
+            # Prefer qualifier in name over qualifier arg
+            [name, qualifier] = name.split(":")
+
+        # Find without qualifier
         if qualifier is None:
-            return self._get_latest(name)
+            return self.get_function_by_name_forbid_qualifier(name)
 
+        if name not in self._functions:
+            raise self.construct_unknown_function_exception(name, qualifier)
+
+        # Find by latest
         if qualifier.lower() == "$latest":
             return self._functions[name]["latest"]
 
+        # Find by version
         found_version = self._get_version(name, qualifier)
         if found_version:
             return found_version
 
+        # Find by alias
         aliases = self._get_function_aliases(name)
-
         if qualifier in aliases:
-            alias = aliases[qualifier]
-            return self._get_version(name, alias.function_version)
+            alias_version = aliases[qualifier].function_version
 
-        return None
+            # Find by alias pointing to latest
+            if alias_version.lower() == "$latest":
+                return self._functions[name]["latest"]
+
+            # Find by alias pointing to version
+            found_alias = self._get_version(name, alias_version)
+            if found_alias:
+                return found_alias
+
+        raise self.construct_unknown_function_exception(name, qualifier)
 
     def list_versions_by_function(self, name: str) -> Iterable[LambdaFunction]:
         if name not in self._functions:
@@ -1438,28 +1489,74 @@ class LambdaStorage(object):
         return sorted(aliases.values(), key=lambda alias: alias.name)
 
     def get_arn(self, arn: str) -> Optional[LambdaFunction]:
+        [arn_without_qualifier, _, _] = self.split_function_arn(arn)
+        return self._arns.get(arn_without_qualifier, None)
+
+    def split_function_arn(self, arn: str) -> Tuple[str, str, Optional[str]]:
+        """
+        Handy utility to parse an ARN into:
+        - ARN without qualifier
+        - Function name
+        - Optional qualifier
+        """
+        qualifier = None
         # Function ARN may contain an alias
         # arn:aws:lambda:region:account_id:function:<fn_name>:<alias_name>
         if ":" in arn.split(":function:")[-1]:
+            qualifier = arn.split(":")[-1]
             # arn = arn:aws:lambda:region:account_id:function:<fn_name>
             arn = ":".join(arn.split(":")[0:-1])
-        return self._arns.get(arn, None)
+        name = arn.split(":")[-1]
+        return arn, name, qualifier
 
-    def get_function_by_name_or_arn(
+    def get_function_by_name_or_arn_forbid_qualifier(
+        self, name_or_arn: str
+    ) -> LambdaFunction:
+        """
+        Get function by name or arn forbidding a qualifier
+        :raises: UnknownFunctionException if function not found
+        :raises: InvalidParameterValue if qualifier is provided
+        """
+
+        if name_or_arn.startswith("arn:aws"):
+            [_, name, qualifier] = self.split_function_arn(name_or_arn)
+
+            if qualifier is not None:
+                raise InvalidParameterValueException("Cannot provide qualifier")
+
+            return self.get_function_by_name_forbid_qualifier(name)
+        else:
+            # name_or_arn is not an arn
+            return self.get_function_by_name_forbid_qualifier(name_or_arn)
+
+    def get_function_by_name_or_arn_with_qualifier(
         self, name_or_arn: str, qualifier: Optional[str] = None
     ) -> LambdaFunction:
-        fn = self.get_function_by_name(name_or_arn, qualifier) or self.get_arn(
-            name_or_arn
-        )
-        if fn is None:
-            if name_or_arn.startswith("arn:aws"):
-                arn = name_or_arn
-            else:
-                arn = make_function_arn(self.region_name, self.account_id, name_or_arn)
-            if qualifier:
+        """
+        Get function by name or arn with an optional qualifier
+        :raises: UnknownFunctionException if function not found
+        """
+
+        if name_or_arn.startswith("arn:aws"):
+            [_, name, qualifier_in_arn] = self.split_function_arn(name_or_arn)
+            return self.get_function_by_name_with_qualifier(
+                name, qualifier_in_arn or qualifier
+            )
+        else:
+            return self.get_function_by_name_with_qualifier(name_or_arn, qualifier)
+
+    def construct_unknown_function_exception(
+        self, name_or_arn: str, qualifier: Optional[str] = None
+    ) -> UnknownFunctionException:
+        if name_or_arn.startswith("arn:aws"):
+            arn = name_or_arn
+        else:
+            # name_or_arn is a function name with optional qualifier <func_name>[:<qualifier>]
+            arn = make_function_arn(self.region_name, self.account_id, name_or_arn)
+            # Append explicit qualifier to arn only if the name doesn't already have it
+            if qualifier and ":" not in name_or_arn:
                 arn = f"{arn}:{qualifier}"
-            raise UnknownFunctionException(arn)
-        return fn
+        return UnknownFunctionException(arn)
 
     def put_function(self, fn: LambdaFunction) -> None:
         valid_role = re.match(InvalidRoleFormat.pattern, fn.role)
@@ -1487,7 +1584,7 @@ class LambdaStorage(object):
     def publish_function(
         self, name_or_arn: str, description: str = ""
     ) -> Optional[LambdaFunction]:
-        function = self.get_function_by_name_or_arn(name_or_arn)
+        function = self.get_function_by_name_or_arn_forbid_qualifier(name_or_arn)
         name = function.function_name
         if name not in self._functions:
             return None
@@ -1512,7 +1609,19 @@ class LambdaStorage(object):
         return fn
 
     def del_function(self, name_or_arn: str, qualifier: Optional[str] = None) -> None:
-        function = self.get_function_by_name_or_arn(name_or_arn, qualifier)
+        # Qualifier may be explicitly passed or part of function name or ARN, extract it here
+        if name_or_arn.startswith("arn:aws"):
+            # Extract from ARN
+            if ":" in name_or_arn.split(":function:")[-1]:
+                qualifier = name_or_arn.split(":")[-1]
+        else:
+            # Extract from function name
+            if ":" in name_or_arn:
+                qualifier = name_or_arn.split(":")[1]
+
+        function = self.get_function_by_name_or_arn_with_qualifier(
+            name_or_arn, qualifier
+        )
         name = function.function_name
         if not qualifier:
             # Something is still reffing this so delete all arns
@@ -1524,8 +1633,11 @@ class LambdaStorage(object):
 
             del self._functions[name]
 
-        elif qualifier == "$LATEST":
-            self._functions[name]["latest"] = None
+        else:
+            if qualifier == "$LATEST":
+                self._functions[name]["latest"] = None
+            else:
+                self._functions[name]["versions"].remove(function)
 
             # If theres no functions left
             if (
@@ -1534,18 +1646,6 @@ class LambdaStorage(object):
             ):
                 del self._functions[name]
 
-        else:
-            fn = self.get_function_by_name(name, qualifier)
-            if fn:
-                self._functions[name]["versions"].remove(fn)
-
-                # If theres no functions left
-                if (
-                    not self._functions[name]["versions"]
-                    and not self._functions[name]["latest"]
-                ):
-                    del self._functions[name]
-
         self._aliases[function.function_arn] = {}
 
     def all(self) -> Iterable[LambdaFunction]:
@@ -1673,6 +1773,8 @@ class LambdaBackend(BaseBackend):
         # Note that this option will be ignored if MOTO_DOCKER_NETWORK_NAME is also set
         MOTO_DOCKER_NETWORK_MODE=host moto_server
 
+    _-_-_-_
+
     The Docker images used by Moto are taken from the following repositories:
 
     - `mlupin/docker-lambda` (for recent versions)
@@ -1684,6 +1786,8 @@ class LambdaBackend(BaseBackend):
 
         MOTO_DOCKER_LAMBDA_IMAGE=mlupin/docker-lambda
 
+    _-_-_-_
+
     Use the following environment variable if you want to configure the data directory used by the Docker containers:
 
     .. sourcecode:: bash
@@ -1691,6 +1795,15 @@ class LambdaBackend(BaseBackend):
         MOTO_LAMBDA_DATA_DIR=/tmp/data
 
     .. note:: When using the decorators, a Docker container cannot reach Moto, as the Docker-container loses all mock-context. Any boto3-invocations used within your Lambda will try to connect to AWS.
+
+    _-_-_-_
+
+    If you want to mock the Lambda-containers invocation without starting a Docker-container, use the simple decorator:
+
+    .. sourcecode:: python
+
+        @mock_lambda_simple
+
     """
 
     def __init__(self, region_name: str, account_id: str):
@@ -1773,21 +1886,27 @@ class LambdaBackend(BaseBackend):
         The Qualifier-parameter is not yet implemented.
         Function URLs are not yet mocked, so invoking them will fail
         """
-        function = self._lambdas.get_function_by_name_or_arn(name_or_arn)
+        function = self._lambdas.get_function_by_name_or_arn_forbid_qualifier(
+            name_or_arn
+        )
         return function.create_url_config(config)
 
     def delete_function_url_config(self, name_or_arn: str) -> None:
         """
         The Qualifier-parameter is not yet implemented
         """
-        function = self._lambdas.get_function_by_name_or_arn(name_or_arn)
+        function = self._lambdas.get_function_by_name_or_arn_forbid_qualifier(
+            name_or_arn
+        )
         function.delete_url_config()
 
     def get_function_url_config(self, name_or_arn: str) -> FunctionUrlConfig:
         """
         The Qualifier-parameter is not yet implemented
         """
-        function = self._lambdas.get_function_by_name_or_arn(name_or_arn)
+        function = self._lambdas.get_function_by_name_or_arn_forbid_qualifier(
+            name_or_arn
+        )
         if not function:
             raise UnknownFunctionException(arn=name_or_arn)
         return function.get_url_config()
@@ -1798,7 +1917,9 @@ class LambdaBackend(BaseBackend):
         """
         The Qualifier-parameter is not yet implemented
         """
-        function = self._lambdas.get_function_by_name_or_arn(name_or_arn)
+        function = self._lambdas.get_function_by_name_or_arn_forbid_qualifier(
+            name_or_arn
+        )
         return function.update_url_config(config)
 
     def create_event_source_mapping(self, spec: Dict[str, Any]) -> EventSourceMapping:
@@ -1808,9 +1929,9 @@ class LambdaBackend(BaseBackend):
                 raise RESTError("InvalidParameterValueException", f"Missing {param}")
 
         # Validate function name
-        func = self._lambdas.get_function_by_name_or_arn(spec.get("FunctionName", ""))
-        if not func:
-            raise RESTError("ResourceNotFoundException", "Invalid FunctionName")
+        func = self._lambdas.get_function_by_name_or_arn_with_qualifier(
+            spec.get("FunctionName", "")
+        )
 
         # Validate queue
         sqs_backend = sqs_backends[self.account_id][self.region_name]
@@ -1877,7 +1998,7 @@ class LambdaBackend(BaseBackend):
     def get_function(
         self, function_name_or_arn: str, qualifier: Optional[str] = None
     ) -> LambdaFunction:
-        return self._lambdas.get_function_by_name_or_arn(
+        return self._lambdas.get_function_by_name_or_arn_with_qualifier(
             function_name_or_arn, qualifier
         )
 
@@ -1902,7 +2023,9 @@ class LambdaBackend(BaseBackend):
 
         for key in spec.keys():
             if key == "FunctionName":
-                func = self._lambdas.get_function_by_name_or_arn(spec[key])
+                func = self._lambdas.get_function_by_name_or_arn_with_qualifier(
+                    spec[key]
+                )
                 esm.function_arn = func.function_arn
             elif key == "BatchSize":
                 esm.batch_size = spec[key]
@@ -2015,7 +2138,9 @@ class LambdaBackend(BaseBackend):
                 }
             ]
         }
-        func = self._lambdas.get_function_by_name_or_arn(function_name, qualifier)
+        func = self._lambdas.get_function_by_name_or_arn_with_qualifier(
+            function_name, qualifier
+        )
         func.invoke(json.dumps(event), {}, {})
 
     def send_dynamodb_items(
@@ -2066,14 +2191,14 @@ class LambdaBackend(BaseBackend):
         func.invoke(json.dumps(event), {}, {})  # type: ignore[union-attr]
 
     def list_tags(self, resource: str) -> Dict[str, str]:
-        return self._lambdas.get_function_by_name_or_arn(resource).tags
+        return self._lambdas.get_function_by_name_or_arn_with_qualifier(resource).tags
 
     def tag_resource(self, resource: str, tags: Dict[str, str]) -> None:
-        fn = self._lambdas.get_function_by_name_or_arn(resource)
+        fn = self._lambdas.get_function_by_name_or_arn_with_qualifier(resource)
         fn.tags.update(tags)
 
     def untag_resource(self, resource: str, tagKeys: List[str]) -> None:
-        fn = self._lambdas.get_function_by_name_or_arn(resource)
+        fn = self._lambdas.get_function_by_name_or_arn_with_qualifier(resource)
         for key in tagKeys:
             fn.tags.pop(key, None)
 
@@ -2093,10 +2218,10 @@ class LambdaBackend(BaseBackend):
         fn = self.get_function(function_name)
         return fn.get_code_signing_config()
 
-    def get_policy(self, function_name: str) -> str:
-        fn = self.get_function(function_name)
-        if not fn:
-            raise UnknownFunctionException(function_name)
+    def get_policy(self, function_name: str, qualifier: Optional[str] = None) -> str:
+        fn = self._lambdas.get_function_by_name_or_arn_with_qualifier(
+            function_name, qualifier
+        )
         return fn.policy.wire_format()  # type: ignore[union-attr]
 
     def update_function_code(
@@ -2115,7 +2240,7 @@ class LambdaBackend(BaseBackend):
     ) -> Optional[Dict[str, Any]]:
         fn = self.get_function(function_name, qualifier)
 
-        return fn.update_configuration(body) if fn else None
+        return fn.update_configuration(body)
 
     def invoke(
         self,
@@ -2129,12 +2254,9 @@ class LambdaBackend(BaseBackend):
         Invoking a Function with PackageType=Image is not yet supported.
         """
         fn = self.get_function(function_name, qualifier)
-        if fn:
-            payload = fn.invoke(body, headers, response_headers)
-            response_headers["Content-Length"] = str(len(payload))
-            return payload
-        else:
-            return None
+        payload = fn.invoke(body, headers, response_headers)
+        response_headers["Content-Length"] = str(len(payload))
+        return payload
 
     def put_function_concurrency(
         self, function_name: str, reserved_concurrency: str
