@@ -1,4 +1,5 @@
 from moto.core.responses import BaseResponse
+from moto.utilities.aws_headers import amzn_request_id
 from .models import batch_backends, BatchBackend
 from urllib.parse import urlsplit, unquote
 
@@ -22,6 +23,7 @@ class BatchResponse(BaseResponse):
         return urlsplit(self.uri).path.lstrip("/").split("/")[1]
 
     # CreateComputeEnvironment
+    @amzn_request_id
     def createcomputeenvironment(self) -> str:
         compute_env_name = self._get_param("computeEnvironmentName")
         compute_resource = self._get_param("computeResources")
@@ -42,6 +44,7 @@ class BatchResponse(BaseResponse):
         return json.dumps(result)
 
     # DescribeComputeEnvironments
+    @amzn_request_id
     def describecomputeenvironments(self) -> str:
         compute_environments = self._get_param("computeEnvironments")
 
@@ -51,6 +54,7 @@ class BatchResponse(BaseResponse):
         return json.dumps(result)
 
     # DeleteComputeEnvironment
+    @amzn_request_id
     def deletecomputeenvironment(self) -> str:
         compute_environment = self._get_param("computeEnvironment")
 
@@ -59,6 +63,7 @@ class BatchResponse(BaseResponse):
         return ""
 
     # UpdateComputeEnvironment
+    @amzn_request_id
     def updatecomputeenvironment(self) -> str:
         compute_env_name = self._get_param("computeEnvironment")
         compute_resource = self._get_param("computeResources")
@@ -77,9 +82,11 @@ class BatchResponse(BaseResponse):
         return json.dumps(result)
 
     # CreateJobQueue
+    @amzn_request_id
     def createjobqueue(self) -> str:
         compute_env_order = self._get_param("computeEnvironmentOrder")
         queue_name = self._get_param("jobQueueName")
+        schedule_policy = self._get_param("schedulingPolicyArn")
         priority = self._get_param("priority")
         state = self._get_param("state")
         tags = self._get_param("tags")
@@ -87,6 +94,7 @@ class BatchResponse(BaseResponse):
         name, arn = self.batch_backend.create_job_queue(
             queue_name=queue_name,
             priority=priority,
+            schedule_policy=schedule_policy,
             state=state,
             compute_env_order=compute_env_order,
             tags=tags,
@@ -97,6 +105,7 @@ class BatchResponse(BaseResponse):
         return json.dumps(result)
 
     # DescribeJobQueues
+    @amzn_request_id
     def describejobqueues(self) -> str:
         job_queues = self._get_param("jobQueues")
 
@@ -106,9 +115,11 @@ class BatchResponse(BaseResponse):
         return json.dumps(result)
 
     # UpdateJobQueue
+    @amzn_request_id
     def updatejobqueue(self) -> str:
         compute_env_order = self._get_param("computeEnvironmentOrder")
         queue_name = self._get_param("jobQueue")
+        schedule_policy = self._get_param("schedulingPolicyArn")
         priority = self._get_param("priority")
         state = self._get_param("state")
 
@@ -117,6 +128,7 @@ class BatchResponse(BaseResponse):
             priority=priority,
             state=state,
             compute_env_order=compute_env_order,
+            schedule_policy=schedule_policy,
         )
 
         result = {"jobQueueArn": arn, "jobQueueName": name}
@@ -124,6 +136,7 @@ class BatchResponse(BaseResponse):
         return json.dumps(result)
 
     # DeleteJobQueue
+    @amzn_request_id
     def deletejobqueue(self) -> str:
         queue_name = self._get_param("jobQueue")
 
@@ -132,6 +145,7 @@ class BatchResponse(BaseResponse):
         return ""
 
     # RegisterJobDefinition
+    @amzn_request_id
     def registerjobdefinition(self) -> str:
         container_properties = self._get_param("containerProperties")
         node_properties = self._get_param("nodeProperties")
@@ -165,6 +179,7 @@ class BatchResponse(BaseResponse):
         return json.dumps(result)
 
     # DeregisterJobDefinition
+    @amzn_request_id
     def deregisterjobdefinition(self) -> str:
         queue_name = self._get_param("jobDefinition")
 
@@ -173,6 +188,7 @@ class BatchResponse(BaseResponse):
         return ""
 
     # DescribeJobDefinitions
+    @amzn_request_id
     def describejobdefinitions(self) -> str:
         job_def_name = self._get_param("jobDefinitionName")
         job_def_list = self._get_param("jobDefinitions")
@@ -186,6 +202,7 @@ class BatchResponse(BaseResponse):
         return json.dumps(result)
 
     # SubmitJob
+    @amzn_request_id
     def submitjob(self) -> str:
         container_overrides = self._get_param("containerOverrides")
         depends_on = self._get_param("dependsOn")
@@ -193,27 +210,31 @@ class BatchResponse(BaseResponse):
         job_name = self._get_param("jobName")
         job_queue = self._get_param("jobQueue")
         timeout = self._get_param("timeout")
+        array_properties = self._get_param("arrayProperties", {})
 
-        name, job_id = self.batch_backend.submit_job(
+        name, job_id, job_arn = self.batch_backend.submit_job(
             job_name,
             job_def,
             job_queue,
             depends_on=depends_on,
             container_overrides=container_overrides,
             timeout=timeout,
+            array_properties=array_properties,
         )
 
-        result = {"jobId": job_id, "jobName": name}
+        result = {"jobId": job_id, "jobName": name, "jobArn": job_arn}
 
         return json.dumps(result)
 
     # DescribeJobs
+    @amzn_request_id
     def describejobs(self) -> str:
         jobs = self._get_param("jobs")
 
         return json.dumps({"jobs": self.batch_backend.describe_jobs(jobs)})
 
     # ListJobs
+    @amzn_request_id
     def listjobs(self) -> str:
         job_queue = self._get_param("jobQueue")
         job_status = self._get_param("jobStatus")
@@ -225,6 +246,7 @@ class BatchResponse(BaseResponse):
         return json.dumps(result)
 
     # TerminateJob
+    @amzn_request_id
     def terminatejob(self) -> str:
         job_id = self._get_param("jobId")
         reason = self._get_param("reason")
@@ -234,6 +256,7 @@ class BatchResponse(BaseResponse):
         return ""
 
     # CancelJob
+    @amzn_request_id
     def canceljob(self) -> str:
         job_id = self._get_param("jobId")
         reason = self._get_param("reason")
@@ -241,6 +264,7 @@ class BatchResponse(BaseResponse):
 
         return ""
 
+    @amzn_request_id
     def tags(self) -> str:
         resource_arn = unquote(self.path).split("/v1/tags/")[-1]
         tags = self._get_param("tags")
@@ -253,3 +277,41 @@ class BatchResponse(BaseResponse):
             tag_keys = self.querystring.get("tagKeys")
             self.batch_backend.untag_resource(resource_arn, tag_keys)  # type: ignore[arg-type]
         return ""
+
+    @amzn_request_id
+    def createschedulingpolicy(self) -> str:
+        body = json.loads(self.body)
+        name = body.get("name")
+        fairshare_policy = body.get("fairsharePolicy") or {}
+        tags = body.get("tags")
+        policy = self.batch_backend.create_scheduling_policy(
+            name, fairshare_policy, tags
+        )
+        return json.dumps(policy.to_dict(create=True))
+
+    @amzn_request_id
+    def describeschedulingpolicies(self) -> str:
+        body = json.loads(self.body)
+        arns = body.get("arns") or []
+        policies = self.batch_backend.describe_scheduling_policies(arns)
+        return json.dumps({"schedulingPolicies": [pol.to_dict() for pol in policies]})
+
+    @amzn_request_id
+    def listschedulingpolicies(self) -> str:
+        arns = self.batch_backend.list_scheduling_policies()
+        return json.dumps({"schedulingPolicies": [{"arn": arn} for arn in arns]})
+
+    @amzn_request_id
+    def deleteschedulingpolicy(self) -> str:
+        body = json.loads(self.body)
+        arn = body["arn"]
+        self.batch_backend.delete_scheduling_policy(arn)
+        return ""
+
+    @amzn_request_id
+    def updateschedulingpolicy(self) -> str:
+        body = json.loads(self.body)
+        arn = body.get("arn")
+        fairshare_policy = body.get("fairsharePolicy") or {}
+        self.batch_backend.update_scheduling_policy(arn, fairshare_policy)
+        return ""
