@@ -1,13 +1,12 @@
 import datetime
 import inspect
 import re
-import unicodedata
 from botocore.exceptions import ClientError
 from gzip import decompress
 from typing import Any, Optional, List, Callable, Dict, Tuple
-from urllib.parse import urlparse, unquote
+from urllib.parse import urlparse
 from .common_types import TYPE_RESPONSE
-from .versions import is_werkzeug_2_3_x, PYTHON_311
+from .versions import PYTHON_311
 
 
 def camelcase_to_underscores(argument: str) -> str:
@@ -339,98 +338,5 @@ def params_sort_function(item: Tuple[str, Any]) -> Tuple[str, Any]:
     return item
 
 
-def normalize_werkzeug_path(path: str) -> str:
-    if is_werkzeug_2_3_x():
-        # New versions of werkzeug expose a quoted path
-        #   %40connections
-        #
-        # Older versions (and botocore requests) expose the original:
-        #   @connections
-        #
-        # We're unquoting the path here manually, so it behaves the same as botocore requests and requests coming in from old werkzeug versions.
-        #
-        return _unquote_hex_characters(path)
-    else:
-        return unquote(path)
-
-
-def _unquote_hex_characters(path: str) -> str:
-    allowed_characters = ["%2F"]  # /
-    # Path can contain a single hex character
-    #    my%3Fchar
-    #
-    # Path can also contain multiple hex characters in a row
-    #    %AA%AB%AC
-    #
-    # This is how complex unicode characters, such as smileys, are encoded.
-    # Note that these particular characters do not translate to anything useful
-    # For the sake of simplicy, let's assume that it translates to a smiley: :)
-    #
-    # Just to make things interesting, they could be found right next to eachother:
-    #    my%3F%AA%AB%ACchar
-    #
-    # Which should translate to my?:)char
-
-    # char_ranges contains all consecutie hex characters:
-    # [(2, 5, %3F), (0, 9, %AA%AB%AC)]
-    char_ranges = [
-        (m.start(0), m.end(0)) for m in re.finditer("(%[0-9A-F][0-9A-F])+", path)
-    ]
-
-    # characters_found will contain the replacement characters
-    # [(2, 5, '?'), (0, 9, ':)')]
-    characters_found: List[Tuple[int, int, str]] = []
-    for char_range in char_ranges:
-        range_start, range_end = char_range
-        possible_combo_start = range_start
-        possible_combo_end = range_end
-        while possible_combo_start < possible_combo_end:
-            # For every range, create combinations of possibilities
-            #    iter 1:   %AA%AB%AC
-            #    iter 2:   %AA%AB
-            #    iter3:    %AA
-            possible_char = path[possible_combo_start:possible_combo_end]
-
-            if possible_char in allowed_characters:
-                # Werkzeug has already converted these characters for us
-                possible_combo_end -= 3
-                continue
-            try:
-                start_of_raw_repr = possible_combo_start + len(characters_found)
-                end_of_raw_repr = start_of_raw_repr + len(possible_char)
-                # Verify that the current possibility is a known unicode character
-                unicodedata.category(unquote(possible_char))
-                characters_found.append(
-                    (start_of_raw_repr, end_of_raw_repr, unquote(possible_char))
-                )
-                if range_end == possible_combo_end:
-                    # We've matched on the full phrase:
-                    # %AA%AB%AC
-                    break
-                else:
-                    # we matched on %AA%AB
-                    # reset the indexes, and try to match %AC next
-                    possible_combo_start = possible_combo_end
-                    possible_combo_end = range_end
-            except:  # noqa: E722 Do not use bare except
-                # 'unicodedata.category' would have thrown an error, meaning:
-                # %AA%AB%AC does not exist
-                # Try the next possibility:
-                # %AA%AB
-                possible_combo_end -= 3
-
-    # Replace the hex characters with the appropriate unicode representation
-    char_offset = 0
-    for char_pos in characters_found:
-        combo_start, combo_end, character = char_pos
-        path = (
-            path[0 : combo_start - char_offset]
-            + character
-            + path[combo_end - char_offset :]
-        )
-        char_offset += (combo_end - combo_start) + len(character) - 1
-    return path
-
-
 def gzip_decompress(body: bytes) -> bytes:
     return decompress(body)
