@@ -1,6 +1,6 @@
 import json
 from typing import Any, Dict, Union
-from urllib.parse import urlparse
+from urllib.parse import unquote
 
 from moto.core.common_types import TYPE_RESPONSE
 from moto.core.responses import BaseResponse
@@ -36,12 +36,11 @@ class DataBrewResponse(BaseResponse):
         )
 
     @amzn_request_id
-    def delete_recipe_version(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return,misc]
+    def delete_recipe_version(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
         self.setup_class(request, full_url, headers)
         # https://docs.aws.amazon.com/databrew/latest/dg/API_DeleteRecipeVersion.html
         if request.method == "DELETE":
-            parsed_url = urlparse(full_url)
-            split_path = parsed_url.path.strip("/").split("/")
+            split_path = self._get_path().strip("/").split("/")
             recipe_name = split_path[1]
             recipe_version = split_path[3]
             self.databrew_backend.delete_recipe_version(recipe_name, recipe_version)
@@ -51,6 +50,9 @@ class DataBrewResponse(BaseResponse):
                 json.dumps({"Name": recipe_name, "RecipeVersion": recipe_version}),
             )
 
+    def _get_path(self) -> str:
+        return unquote(self.parsed_url.path)
+
     @amzn_request_id
     def list_recipes(self) -> str:
         # https://docs.aws.amazon.com/databrew/latest/dg/API_ListRecipes.html
@@ -76,7 +78,7 @@ class DataBrewResponse(BaseResponse):
         )
 
     @amzn_request_id
-    def list_recipe_versions(self, request: Any, full_url: str, headers: Any) -> str:  # type: ignore[return,misc]
+    def list_recipe_versions(self, request: Any, full_url: str, headers: Any) -> str:
         # https://docs.aws.amazon.com/databrew/latest/dg/API_ListRecipeVersions.html
         self.setup_class(request, full_url, headers)
         recipe_name = self._get_param("Name", self._get_param("name"))
@@ -97,11 +99,10 @@ class DataBrewResponse(BaseResponse):
         )
 
     @amzn_request_id
-    def publish_recipe(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return,misc]
+    def publish_recipe(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
         self.setup_class(request, full_url, headers)
         if request.method == "POST":
-            parsed_url = urlparse(full_url)
-            recipe_name = parsed_url.path.strip("/").split("/", 2)[1]
+            recipe_name = self._get_path().strip("/").split("/", 2)[1]
             recipe_description = self.parameters.get("Description")
             self.databrew_backend.publish_recipe(recipe_name, recipe_description)
             return 200, {}, json.dumps({"Name": recipe_name})
@@ -126,11 +127,10 @@ class DataBrewResponse(BaseResponse):
         return 200, {}, json.dumps(recipe.as_dict())
 
     @amzn_request_id
-    def recipe_response(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[misc,return]
+    def recipe_response(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
         self.setup_class(request, full_url, headers)
-        parsed_url = urlparse(full_url)
 
-        recipe_name = parsed_url.path.rstrip("/").rsplit("/", 1)[1]
+        recipe_name = self._get_path().rstrip("/").rsplit("/", 1)[1]
 
         if request.method == "PUT":
             return self.put_recipe_response(recipe_name)
@@ -178,11 +178,10 @@ class DataBrewResponse(BaseResponse):
         return 200, {}, json.dumps({"Name": ruleset_name})
 
     @amzn_request_id
-    def ruleset_response(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[misc,return]
+    def ruleset_response(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
         self.setup_class(request, full_url, headers)
-        parsed_url = urlparse(full_url)
 
-        ruleset_name = parsed_url.path.split("/")[-1]
+        ruleset_name = self._get_path().split("/")[-1]
 
         if request.method == "PUT":
             response = self.put_ruleset_response(ruleset_name)
@@ -283,11 +282,10 @@ class DataBrewResponse(BaseResponse):
         return 200, {}, json.dumps(dataset.as_dict())
 
     @amzn_request_id
-    def dataset_response(self, request: Any, full_url: str, headers: Any) -> Union[str, TYPE_RESPONSE]:  # type: ignore[misc,return]
+    def dataset_response(self, request: Any, full_url: str, headers: Any) -> Union[str, TYPE_RESPONSE]:  # type: ignore[return]
         self.setup_class(request, full_url, headers)
-        parsed_url = urlparse(full_url)
 
-        dataset_name = parsed_url.path.split("/")[-1]
+        dataset_name = self._get_path().split("/")[-1]
 
         if request.method == "POST":
             return self.create_dataset()
@@ -304,7 +302,7 @@ class DataBrewResponse(BaseResponse):
 
     # region Jobs
     @amzn_request_id
-    def list_jobs(self, request: Any, full_url: str, headers: Any) -> str:  # type: ignore[misc,return]
+    def list_jobs(self, request: Any, full_url: str, headers: Any) -> str:
         # https://docs.aws.amazon.com/databrew/latest/dg/API_ListJobs.html
         self.setup_class(request, full_url, headers)
         dataset_name = self._get_param("datasetName")
@@ -337,11 +335,10 @@ class DataBrewResponse(BaseResponse):
         return 200, {}, json.dumps({"Name": job_name})
 
     @amzn_request_id
-    def job_response(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[misc,return]
+    def job_response(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
         self.setup_class(request, full_url, headers)
-        parsed_url = urlparse(full_url)
 
-        job_name = parsed_url.path.rstrip("/").rsplit("/", 1)[1]
+        job_name = self._get_path().rstrip("/").rsplit("/", 1)[1]
 
         if request.method == "GET":
             return self.get_job_response(job_name)
@@ -428,21 +425,19 @@ class DataBrewResponse(BaseResponse):
         return json.dumps(self.databrew_backend.update_recipe_job(**kwargs).as_dict())
 
     @amzn_request_id
-    def profile_job_response(self, request: Any, full_url: str, headers: Any) -> str:  # type: ignore[misc,return]
+    def profile_job_response(self, request: Any, full_url: str, headers: Any) -> str:  # type: ignore[return]
         self.setup_class(request, full_url, headers)
-        parsed_url = urlparse(full_url)
 
-        job_name = parsed_url.path.rstrip("/").rsplit("/", 1)[1]
+        job_name = self._get_path().rstrip("/").rsplit("/", 1)[1]
 
         if request.method == "PUT":
             return self.update_profile_job_response(job_name)
 
     @amzn_request_id
-    def recipe_job_response(self, request: Any, full_url: str, headers: Any) -> str:  # type: ignore[misc,return]
+    def recipe_job_response(self, request: Any, full_url: str, headers: Any) -> str:  # type: ignore[return]
         self.setup_class(request, full_url, headers)
-        parsed_url = urlparse(full_url)
 
-        job_name = parsed_url.path.rstrip("/").rsplit("/", 1)[1]
+        job_name = self._get_path().rstrip("/").rsplit("/", 1)[1]
 
         if request.method == "PUT":
             return self.update_recipe_job_response(job_name)
