@@ -1,15 +1,18 @@
 import json
-from typing import Any, List, Optional
+from typing import Any, Dict, List, Optional
 from moto.core.exceptions import JsonRESTError
 from moto.dynamodb.limits import HASH_KEY_MAX_LENGTH, RANGE_KEY_MAX_LENGTH
 
 
+ERROR_TYPE_PREFIX = "com.amazonaws.dynamodb.v20120810#"
+
+
 class DynamodbException(JsonRESTError):
     pass
 
 
 class MockValidationException(DynamodbException):
-    error_type = "com.amazonaws.dynamodb.v20111205#ValidationException"
+    error_type = ERROR_TYPE_PREFIX + "ValidationException"
 
     def __init__(self, message: str):
         super().__init__(MockValidationException.error_type, message=message)
@@ -190,12 +193,33 @@ class IncorrectDataType(MockValidationException):
 
 
 class ConditionalCheckFailed(DynamodbException):
-    error_type = "com.amazonaws.dynamodb.v20111205#ConditionalCheckFailedException"
+    error_type = ERROR_TYPE_PREFIX + "ConditionalCheckFailedException"
 
-    def __init__(self, msg: Optional[str] = None):
-        super().__init__(
-            ConditionalCheckFailed.error_type, msg or "The conditional request failed"
-        )
+    def __init__(
+        self, msg: Optional[str] = None, item: Optional[Dict[str, Any]] = None
+    ):
+        _msg = msg or "The conditional request failed"
+        super().__init__(ConditionalCheckFailed.error_type, _msg)
+        if item:
+            self.description = json.dumps(
+                {
+                    "__type": ConditionalCheckFailed.error_type,
+                    # Note the uppercase Message
+                    # This ensures the message is only part of the 'error': {'message': .., 'code': ..}
+                    "Message": _msg,
+                    "Item": item,
+                }
+            )
+        else:
+            self.description = json.dumps(
+                {
+                    "__type": ConditionalCheckFailed.error_type,
+                    # Note that lowercase 'message'
+                    # This ensures that 'message' is a top-level field in the response
+                    # (in addition to being part of the 'error': {'message': .., 'code': ..}
+                    "message": _msg,
+                }
+            )
 
 
 class TransactionCanceledException(DynamodbException):
@@ -209,10 +233,13 @@ class TransactionCanceledException(DynamodbException):
         super().__init__(
             error_type=TransactionCanceledException.error_type, message=msg
         )
-        reasons = [
-            {"Code": code, "Message": message, **item} if code else {"Code": "None"}
-            for code, message, item in errors
-        ]
+        reasons = []
+        for code, message, item in errors:
+            r = {"Code": code, "Message": message} if code else {"Code": "None"}
+            if item:
+                r["Item"] = item
+            reasons.append(r)
+
         self.description = json.dumps(
             {
                 "__type": TransactionCanceledException.error_type,
@@ -279,44 +306,47 @@ class TooManyAddClauses(InvalidUpdateExpression):
 
 
 class ResourceNotFoundException(JsonRESTError):
-    def __init__(self, msg: Optional[str] = None):
-        err = "com.amazonaws.dynamodb.v20111205#ResourceNotFoundException"
-        super().__init__(err, msg or "Requested resource not found")
+    def __init__(self, msg: Optional[str] = None, table_name: Optional[str] = None):
+        err = ERROR_TYPE_PREFIX + "ResourceNotFoundException"
+        default_msg = "Requested resource not found"
+        if table_name is not None:
+            default_msg += f": Table: {table_name} not found"
+        super().__init__(err, msg or default_msg)
 
 
 class TableNotFoundException(JsonRESTError):
     def __init__(self, name: str):
-        err = "com.amazonaws.dynamodb.v20111205#TableNotFoundException"
+        err = ERROR_TYPE_PREFIX + "TableNotFoundException"
         super().__init__(err, f"Table not found: {name}")
 
 
 class SourceTableNotFoundException(JsonRESTError):
     def __init__(self, source_table_name: str):
-        er = "com.amazonaws.dynamodb.v20111205#SourceTableNotFoundException"
+        er = ERROR_TYPE_PREFIX + "SourceTableNotFoundException"
         super().__init__(er, f"Source table not found: {source_table_name}")
 
 
 class BackupNotFoundException(JsonRESTError):
     def __init__(self, backup_arn: str):
-        er = "com.amazonaws.dynamodb.v20111205#BackupNotFoundException"
+        er = ERROR_TYPE_PREFIX + "BackupNotFoundException"
         super().__init__(er, f"Backup not found: {backup_arn}")
 
 
 class TableAlreadyExistsException(JsonRESTError):
     def __init__(self, target_table_name: str):
-        er = "com.amazonaws.dynamodb.v20111205#TableAlreadyExistsException"
+        er = ERROR_TYPE_PREFIX + "TableAlreadyExistsException"
         super().__init__(er, f"Table already exists: {target_table_name}")
 
 
 class ResourceInUseException(JsonRESTError):
-    def __init__(self) -> None:
-        er = "com.amazonaws.dynamodb.v20111205#ResourceInUseException"
-        super().__init__(er, "Resource in use")
+    def __init__(self, msg: Optional[str] = None) -> None:
+        er = ERROR_TYPE_PREFIX + "ResourceInUseException"
+        super().__init__(er, msg or "Resource in use")
 
 
 class StreamAlreadyEnabledException(JsonRESTError):
     def __init__(self) -> None:
-        er = "com.amazonaws.dynamodb.v20111205#ResourceInUseException"
+        er = ERROR_TYPE_PREFIX + "ResourceInUseException"
         super().__init__(er, "Cannot enable stream")
 
 
@@ -338,3 +368,9 @@ class TransactWriteSingleOpException(MockValidationException):
 class SerializationException(DynamodbException):
     def __init__(self, msg: str):
         super().__init__(error_type="SerializationException", message=msg)
+
+
+class UnknownKeyType(MockValidationException):
+    def __init__(self, key_type: str, position: str):
+        msg = f"1 validation error detected: Value '{key_type}' at '{position}' failed to satisfy constraint: Member must satisfy enum value set: [HASH, RANGE]"
+        super().__init__(msg)
