@@ -1,39 +1,41 @@
 """Handles incoming ebs requests, invokes methods, returns responses."""
 import json
+from typing import Any
 
 from moto.core.responses import BaseResponse
-from .models import ebs_backends
+from moto.core.common_types import TYPE_RESPONSE
+from .models import ebs_backends, EBSBackend
 
 
 class EBSResponse(BaseResponse):
     """Handler for EBS requests and responses."""
 
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__(service_name="ebs")
 
     @property
-    def ebs_backend(self):
+    def ebs_backend(self) -> EBSBackend:
         """Return backend instance specific for this region."""
         return ebs_backends[self.current_account][self.region]
 
-    def snapshots(self, request, full_url, headers):
+    def snapshots(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
         self.setup_class(request, full_url, headers)
         if request.method == "POST":
             return self.start_snapshot()
 
-    def snapshot_block(self, request, full_url, headers):
-        self.setup_class(request, full_url, headers)
+    def snapshot_block(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
+        self.setup_class(request, full_url, headers, use_raw_body=True)
         if request.method == "PUT":
             return self.put_snapshot_block(full_url, headers)
         if request.method == "GET":
             return self.get_snapshot_block()
 
-    def snapshot_blocks(self, request, full_url, headers):
+    def snapshot_blocks(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
         self.setup_class(request, full_url, headers)
         if request.method == "GET":
             return self.list_snapshot_blocks()
 
-    def start_snapshot(self):
+    def start_snapshot(self) -> TYPE_RESPONSE:
         """
         The following parameters are not yet implemented: ParentSnapshotId, ClientToken, Encrypted, KmsKeyArn, Timeout
         """
@@ -48,16 +50,18 @@ class EBSResponse(BaseResponse):
         )
         return 200, {}, json.dumps(snapshot.to_json())
 
-    def complete_snapshot(self, request, full_url, headers):
+    def complete_snapshot(
+        self, request: Any, full_url: str, headers: Any
+    ) -> TYPE_RESPONSE:
         """
         The following parameters are not yet supported: ChangedBlocksCount, Checksum, ChecksumAlgorithm, ChecksumAggregationMethod
         """
         self.setup_class(request, full_url, headers)
         snapshot_id = full_url.split("/")[-1]
         status = self.ebs_backend.complete_snapshot(snapshot_id=snapshot_id)
-        return 200, {}, json.dumps(status)
+        return 202, {}, json.dumps(status)
 
-    def put_snapshot_block(self, full_url, headers):
+    def put_snapshot_block(self, full_url: str, headers: Any) -> TYPE_RESPONSE:
         """
         The following parameters are currently not taken into account: DataLength, Progress.
         The Checksum and ChecksumAlgorithm are taken at face-value, but no validation takes place.
@@ -78,7 +82,7 @@ class EBSResponse(BaseResponse):
             data_length=data_length,
         )
         return (
-            200,
+            201,
             {
                 "x-amz-Checksum": checksum,
                 "x-amz-Checksum-Algorithm": checksum_algorithm,
@@ -86,7 +90,7 @@ class EBSResponse(BaseResponse):
             "{}",
         )
 
-    def get_snapshot_block(self):
+    def get_snapshot_block(self) -> TYPE_RESPONSE:
         snapshot_id = self.path.split("/")[-3]
         block_index = self.path.split("/")[-1]
         block = self.ebs_backend.get_snapshot_block(
@@ -100,12 +104,14 @@ class EBSResponse(BaseResponse):
         }
         return 200, headers, block.block_data
 
-    def snapshot_changed_blocks(self, request, full_url, headers):
+    def snapshot_changed_blocks(
+        self, request: Any, full_url: str, headers: Any
+    ) -> TYPE_RESPONSE:
         self.setup_class(request, full_url, headers)
         first_snapshot_id = self._get_params().get("firstSnapshotId")
         second_snapshot_id = self.path.split("/")[-2]
         changed_blocks, snapshot = self.ebs_backend.list_changed_blocks(
-            first_snapshot_id=first_snapshot_id,
+            first_snapshot_id=first_snapshot_id,  # type: ignore[arg-type]
             second_snapshot_id=second_snapshot_id,
         )
         blocks = [
@@ -124,7 +130,7 @@ class EBSResponse(BaseResponse):
             ),
         )
 
-    def list_snapshot_blocks(self):
+    def list_snapshot_blocks(self) -> TYPE_RESPONSE:
         """
         The following parameters are not yet implemented: NextToken, MaxResults, StartingBlockIndex
         """
