@@ -1,4 +1,5 @@
 import json
+from typing import Any
 from moto.core.exceptions import JsonRESTError
 
 
@@ -7,11 +8,13 @@ class MQError(JsonRESTError):
 
 
 class UnknownBroker(MQError):
-    def __init__(self, broker_id):
+    def __init__(self, broker_id: str):
         super().__init__("NotFoundException", "Can't find requested broker")
         self.broker_id = broker_id
 
-    def get_body(self, *args, **kwargs):  # pylint: disable=unused-argument
+    def get_body(
+        self, *args: Any, **kwargs: Any
+    ) -> str:  # pylint: disable=unused-argument
         body = {
             "errorAttribute": "broker-id",
             "message": f"Can't find requested broker [{self.broker_id}]. Make sure your broker exists.",
@@ -20,11 +23,13 @@ class UnknownBroker(MQError):
 
 
 class UnknownConfiguration(MQError):
-    def __init__(self, config_id):
+    def __init__(self, config_id: str):
         super().__init__("NotFoundException", "Can't find requested configuration")
         self.config_id = config_id
 
-    def get_body(self, *args, **kwargs):  # pylint: disable=unused-argument
+    def get_body(
+        self, *args: Any, **kwargs: Any
+    ) -> str:  # pylint: disable=unused-argument
         body = {
             "errorAttribute": "configuration_id",
             "message": f"Can't find requested configuration [{self.config_id}]. Make sure your configuration exists.",
@@ -33,11 +38,13 @@ class UnknownConfiguration(MQError):
 
 
 class UnknownUser(MQError):
-    def __init__(self, username):
+    def __init__(self, username: str):
         super().__init__("NotFoundException", "Can't find requested user")
         self.username = username
 
-    def get_body(self, *args, **kwargs):  # pylint: disable=unused-argument
+    def get_body(
+        self, *args: Any, **kwargs: Any
+    ) -> str:  # pylint: disable=unused-argument
         body = {
             "errorAttribute": "username",
             "message": f"Can't find requested user [{self.username}]. Make sure your user exists.",
@@ -45,25 +52,14 @@ class UnknownUser(MQError):
         return json.dumps(body)
 
 
-class UnsupportedEngineType(MQError):
-    def __init__(self, engine_type):
-        super().__init__("BadRequestException", "")
-        self.engine_type = engine_type
-
-    def get_body(self, *args, **kwargs):  # pylint: disable=unused-argument
-        body = {
-            "errorAttribute": "engineType",
-            "message": f"Broker engine type [{self.engine_type}] does not support configuration.",
-        }
-        return json.dumps(body)
-
-
 class UnknownEngineType(MQError):
-    def __init__(self, engine_type):
+    def __init__(self, engine_type: str):
         super().__init__("BadRequestException", "")
         self.engine_type = engine_type
 
-    def get_body(self, *args, **kwargs):  # pylint: disable=unused-argument
+    def get_body(
+        self, *args: Any, **kwargs: Any
+    ) -> str:  # pylint: disable=unused-argument
         body = {
             "errorAttribute": "engineType",
             "message": f"Broker engine type [{self.engine_type}] is invalid. Valid values are: [ACTIVEMQ]",
