@@ -42,6 +42,7 @@ from moto.s3.exceptions import (
     MissingKey,
     InvalidNotificationDestination,
     MalformedXML,
+    HeadOnDeleteMarker,
     InvalidStorageClass,
     InvalidTargetBucketForLogging,
     CrossLocationLoggingProhibitted,
@@ -88,7 +89,7 @@ class FakeKey(BaseModel, ManagedState):
         self,
         name: str,
         value: bytes,
-        account_id: Optional[str] = None,
+        account_id: str,
         storage: Optional[str] = "STANDARD",
         etag: Optional[str] = None,
         is_versioned: bool = False,
@@ -362,6 +363,7 @@ class FakeMultipart(BaseModel):
         self,
         key_name: str,
         metadata: CaseInsensitiveDict,  # type: ignore
+        account_id: str,
         storage: Optional[str] = None,
         tags: Optional[Dict[str, str]] = None,
         acl: Optional["FakeAcl"] = None,
@@ -370,6 +372,7 @@ class FakeMultipart(BaseModel):
     ):
         self.key_name = key_name
         self.metadata = metadata
+        self.account_id = account_id
         self.storage = storage
         self.tags = tags
         self.acl = acl
@@ -416,7 +419,7 @@ class FakeMultipart(BaseModel):
             raise NoSuchUpload(upload_id=part_id)
 
         key = FakeKey(
-            part_id, value, encryption=self.sse_encryption, kms_key_id=self.kms_key_id  # type: ignore
+            part_id, value, account_id=self.account_id, encryption=self.sse_encryption, kms_key_id=self.kms_key_id  # type: ignore
         )
         if part_id in self.parts:
             # We're overwriting the current part - dispose of it first
@@ -2068,6 +2071,7 @@ class S3Backend(BaseBackend, CloudWatchMetricProvider):
         key_name: str,
         version_id: Optional[str] = None,
         part_number: Optional[str] = None,
+        return_delete_marker: bool = False,
     ) -> Optional[FakeKey]:
         bucket = self.get_bucket(bucket_name)
 
@@ -2090,6 +2094,8 @@ class S3Backend(BaseBackend, CloudWatchMetricProvider):
             key.advance()
             return key
         else:
+            if return_delete_marker and isinstance(key, FakeDeleteMarker):
+                return key  # type: ignore
             return None
 
     def head_object(
@@ -2099,7 +2105,12 @@ class S3Backend(BaseBackend, CloudWatchMetricProvider):
         version_id: Optional[str] = None,
         part_number: Optional[str] = None,
     ) -> Optional[FakeKey]:
-        return self.get_object(bucket_name, key_name, version_id, part_number)
+        obj = self.get_object(
+            bucket_name, key_name, version_id, part_number, return_delete_marker=True
+        )
+        if isinstance(obj, FakeDeleteMarker):
+            raise HeadOnDeleteMarker(obj)
+        return obj
 
     def get_object_acl(self, key: FakeKey) -> Optional[FakeAcl]:
         return key.acl
@@ -2280,6 +2291,7 @@ class S3Backend(BaseBackend, CloudWatchMetricProvider):
         multipart = FakeMultipart(
             key_name,
             metadata,
+            account_id=self.account_id,
             storage=storage_type,
             tags=tags,
             acl=acl,
@@ -2319,7 +2331,7 @@ class S3Backend(BaseBackend, CloudWatchMetricProvider):
         part_id: int,
         src_bucket_name: str,
         src_key_name: str,
-        src_version_id: str,
+        src_version_id: Optional[str],
         start_byte: int,
         end_byte: int,
     ) -> FakeKey:
