@@ -155,14 +155,11 @@ class S3ControlResponse(BaseResponse):
         return account_id, name
 
 
-S3ControlResponseInstance = S3ControlResponse()
-
-
 CREATE_ACCESS_POINT_TEMPLATE = """<CreateAccessPointResult>
   <ResponseMetadata>
     <RequestId>1549581b-12b7-11e3-895e-1334aEXAMPLE</RequestId>
   </ResponseMetadata>
-  <Alias>{{ access_point.name }}</Alias>
+  <Alias>{{ access_point.alias }}</Alias>
   <AccessPointArn>{{ access_point.arn }}</AccessPointArn>
 </CreateAccessPointResult>
 """
