@@ -256,7 +256,7 @@ class SQSResponse(BaseResponse):
                 "AttributeName"
             ) or self.querystring.get("AttributeName")
 
-        attributes = self.sqs_backend.get_queue_attributes(queue_name, attribute_names)  # type: ignore
+        attributes = self.sqs_backend.get_queue_attributes(queue_name, attribute_names)
 
         if self.is_json():
             if len(attributes) == 0:
@@ -730,6 +730,7 @@ class SQSResponse(BaseResponse):
         template = self.response_template(UNTAG_QUEUE_RESPONSE)
         return template.render()
 
+    @jsonify_error
     def list_queue_tags(self) -> str:
         queue_name = self._get_queue_name()
 
